@@ -3,8 +3,8 @@ import json
 import boto3
 import logging
 
-from trell.utils import LogFormatter
-LogFormatter.apply()
+# from trell.utils import LogFormatter
+# LogFormatter.apply()
 
 try:
     secret_name = "data-secret"
